? VERSION
? packages/rpm/doxygen.spec
Index: src/doxygen.cpp
===================================================================
RCS file: /cvsroot/doxygen/src/doxygen.cpp,v
retrieving revision 1.213
diff -u -r1.213 doxygen.cpp
--- src/doxygen.cpp	15 Jan 2006 22:13:58 -0000	1.213
+++ src/doxygen.cpp	3 Mar 2006 14:15:15 -0000
@@ -9102,9 +9102,6 @@
   msg("Generating index page...\n"); 
   writeIndex(*outputList);
 
-  msg("Generating file index...\n");
-  writeFileIndex(*outputList);
-
   msg("Generating example documentation...\n");
   generateExampleDocs();
 
@@ -9118,26 +9115,44 @@
   msg("Generating file documentation...\n");
   generateFileDocs();
   
-  msg("Generating class documentation...\n");
-  generateClassDocs();
-  
   msg("Generating page documentation...\n");
   generatePageDocs();
   
   msg("Generating group documentation...\n");
   generateGroupDocs();
 
-  if (Config_getBool("SHOW_DIRECTORIES"))
+  msg("Generating group index...\n");
+  writeGroupIndex(*outputList);
+ 
+  msg("Generating class documentation...\n");
+  generateClassDocs();
+  
+  if (Config_getBool("HAVE_DOT") && Config_getBool("GRAPHICAL_HIERARCHY"))
   {
-    msg("Generating directory documentation...\n");
-    generateDirDocs(*outputList);
+    msg("Generating graphical class hierarchy...\n");
+    writeGraphicalClassHierarchy(*outputList);
   }
 
   msg("Generating namespace index...\n");
   generateNamespaceDocs();
   
-  msg("Generating group index...\n");
-  writeGroupIndex(*outputList);
+  msg("Generating namespace member index...\n");
+  writeNamespaceMemberIndex(*outputList);
+
+  if (Config_getBool("GENERATE_LEGEND"))
+  {
+    msg("Generating graph info page...\n");
+    writeGraphInfo(*outputList);
+  }
+
+  if (Config_getBool("SHOW_DIRECTORIES"))
+  {
+    msg("Generating directory documentation...\n");
+    generateDirDocs(*outputList);
+  }
+
+  msg("Generating file index...\n");
+  writeFileIndex(*outputList);
  
   if (Config_getBool("SHOW_DIRECTORIES"))
   {
@@ -9151,18 +9166,9 @@
   msg("Generating file member index...\n");
   writeFileMemberIndex(*outputList);
   
-  msg("Generating namespace member index...\n");
-  writeNamespaceMemberIndex(*outputList);
-
   msg("Generating page index...\n");
   writePageIndex(*outputList);
   
-  if (Config_getBool("GENERATE_LEGEND"))
-  {
-    msg("Generating graph info page...\n");
-    writeGraphInfo(*outputList);
-  }
-
   //writeDirDependencyGraph(Config_getString("HTML_OUTPUT"));
   
   if (Config_getBool("GENERATE_RTF"))
@@ -9174,12 +9180,6 @@
     }
   }
   
-  if (Config_getBool("HAVE_DOT") && Config_getBool("GRAPHICAL_HIERARCHY"))
-  {
-    msg("Generating graphical class hierarchy...\n");
-    writeGraphicalClassHierarchy(*outputList);
-  }
-
   if (Doxygen::formulaList.count()>0 && Config_getBool("GENERATE_HTML"))
   {
     msg("Generating bitmaps for formulas in HTML...\n");
Index: src/doxygen.css
===================================================================
RCS file: /cvsroot/doxygen/src/doxygen.css,v
retrieving revision 1.3
diff -u -r1.3 doxygen.css
--- src/doxygen.css	4 Feb 2006 15:33:47 -0000	1.3
+++ src/doxygen.css	3 Mar 2006 14:15:16 -0000
@@ -343,3 +343,15 @@
   font-style: italic;
 }
 /* End Styling for detailed member documentation */
+
+/* for the tree view */
+.ftvtree {
+	font-family: sans-serif;
+	margin:0.5em;
+}
+.directory { font-size: 9pt; font-weight: bold; }
+.directory h3 { margin: 0px; margin-top: 1em; font-size: 11pt; }
+.directory > h3 { margin-top: 0; }
+.directory p { margin: 0px; white-space: nowrap; }
+.directory div { display: none; margin: 0px; }
+.directory img { vertical-align: -30%; }
Index: src/doxygen_css.h
===================================================================
RCS file: /cvsroot/doxygen/src/doxygen_css.h,v
retrieving revision 1.3
diff -u -r1.3 doxygen_css.h
--- src/doxygen_css.h	4 Feb 2006 15:33:47 -0000	1.3
+++ src/doxygen_css.h	3 Mar 2006 14:15:16 -0000
@@ -343,3 +343,16 @@
 "  font-style: italic;\n"
 "}\n"
 "/* End Styling for detailed member documentation */\n"
+"\n"
+"/* for the tree view */\n"
+".ftvtree {\n"
+"	font-family: sans-serif;\n"
+"	margin:0.5em;\n"
+"}\n"
+".directory { font-size: 9pt; font-weight: bold; }\n"
+".directory h3 { margin: 0px; margin-top: 1em; font-size: 11pt; }\n"
+".directory > h3 { margin-top: 0; }\n"
+".directory p { margin: 0px; white-space: nowrap; }\n"
+".directory div { display: none; margin: 0px; }\n"
+".directory img { vertical-align: -30%; }\n"
+"\n"
Index: src/ftvhelp.cpp
===================================================================
RCS file: /cvsroot/doxygen/src/ftvhelp.cpp,v
retrieving revision 1.27
diff -u -r1.27 ftvhelp.cpp
--- src/ftvhelp.cpp	18 Sep 2005 19:25:31 -0000	1.27
+++ src/ftvhelp.cpp	3 Mar 2006 14:15:17 -0000
@@ -653,15 +653,6 @@
     }
     t << "\">" << endl;
     t << "    <title>TreeView</title>\n";
-    t << "    <style type=\"text/css\">\n";
-    t << "    <!--\n";
-    t << "    .directory { font-size: 10pt; font-weight: bold; }\n";
-    t << "    .directory h3 { margin: 0px; margin-top: 1em; font-size: 11pt; }\n";
-    t << "    .directory p { margin: 0px; white-space: nowrap; }\n";
-    t << "    .directory div { display: none; margin: 0px; }\n";
-    t << "    .directory img { vertical-align: middle; }\n";
-    t << "    -->\n";
-    t << "    </style>\n";
     t << "    <script type=\"text/javascript\">\n";
     t << "    <!-- // Hide script from old browsers\n";
     t << "    \n";
@@ -722,7 +713,7 @@
     t << "    </script>\n";
     t << "  </head>\n";
     t << "\n";
-    t << "  <body>\n";
+    t << "  <body class=\"ftvtree\">\n";
     t << "    <div class=\"directory\">\n";
     t << "      <h3>";
     QCString &projName = Config_getString("PROJECT_NAME");
